==> elgg-1.12.16.zip: elgg-1.12.16/mod/messages/languages/gl.php <==
<?php
return array(
	/**
	* Menu items and titles
	*/

	'messages' => "Mensaxes",
	'messages:unreadcount' => "%s sen ler",
	'messages:back' => "Volver ás mensaxes",
	'messages:user' => "Caixa de entrada de %s",
	'messages:posttitle' => "Mensaxes de %s: %s",
	'messages:inbox' => "Caixa de entrada",
	'messages:sent' => "Enviadas",
	'messages:message' => "Mensaxe",
	'messages:title' => "Asunt",
	'messages:to:help' => "Escriba aquí o nome de usuario do destinatario.",
	'messages:replying' => "Mensaxe en resposta a ",
	'messages:sendmessage' => "Enviar unha mensaxe",
	'messages:add' => "Redactar unha mensaxe",
	'messages:sentmessages' => "Mensaxes enviadas",
	'messages:recent' => "Últimas mensaxes",
	'messages:original' => "Mensaxe orixinal",
	'messages:yours' => "Mensaxe súa",
	'messages:toggle' => 'Alternalo todo',
	'messages:markread' => 'Marcar como lida',
	'messages:recipient' => 'Seleccione un destinatario&hellip;',
	'messages:to_user' => 'Para: %s',

	'messages:new' => 'Nova mensaxe',

	'notification:method:site' => 'Siti',

	'messages:error' => 'Non foi posíbel gardar a mensaxe. Inténteo de novo',

	'item:object:messages' => 'Mensaxes',

	/**
	* Status messages
	*/

	'messages:posted' => "Enviouse a mensaxe",
	'messages:success:delete:single' => 'Eliminouse a mensaxe',
	'messages:success:delete' => 'Eliminouse a mensaxe',
	'messages:success:read' => 'Marcouse a mensaxe como lida.',
	'messages:error:messages_not_selected' => 'Non hai ningunha mensaxe seleccionada.',
	'messages:error:delete:single' => 'Non foi posíbel eliminar a mensaxe.',

	/**
	* Email messages
	*/

	'messages:email:subject' => 'Ten unha nova mensaxe.',
	'messages:email:body' => "Ten unha nova mensaxe de %s que di:


	%s


	Para ver as súas mensaxes:

	%s

	Para enviarlle unha mensaxe a %s:

	%s

	Non conteste a este correo.",

	/**
	* Error messages
	*/

	'messages:blank' => "Non pode gardar unha mensaxe co corpo baleiro.",
	'messages:notfound' => "Non foi posíbel atopar a mensaxe indicada.",
	'messages:notdeleted' => "Non foi posíbel eliminar a mensaxe.",
	'messages:nopermission' => "Non ten permisos para modificar a mensaxe.",
	'messages:nomessages' => "Non hai ningunha mensaxe.",
	'messages:user:nonexist' => "Non foi posíbel atopar o destinatario na base de datos de usuarios.",
	'messages:user:blank' => "Non indicou ningún destinatario.",
	'messages:user:self' => "Non pode enviarse unha mensaxe a vostede mesmo.",

	'messages:deleted_sender' => 'Usuario eliminado.',

);

==> elgg-3.3.20.zip: elgg-3.3.20/mod/messages/languages/gl.php <==
<?php
/**
 * Translation file
 *
 * Note: don't change the return array to short notation because Transifex can't handle those during `tx push -s`
 */

return array(
	/**
	* Menu items and titles
	*/

	'messages' => "Mensaxes",
	'messages:unreadcount' => "%s sen ler",
	'messages:user' => "Caixa de entrada de %s",
	'messages:inbox' => "Caixa de entrada",
	'messages:sent' => "Enviadas",
	'messages:message' => "Mensaxe",
	'messages:title' => "Asunt",
	'messages:to:help' => "Escriba aquí o nome de usuario do destinatario.",
	'messages:inbox' => "Caixa de entrada",
	'messages:sendmessage' => "Enviar unha mensaxe",
	'messages:add' => "Redactar unha mensaxe",
	'messages:sentmessages' => "Mensaxes enviadas",
	'messages:toggle' => 'Alternalo todo',
	'messages:markread' => 'Marcar como lida',

	'notification:method:site' => 'Siti',

	'messages:error' => 'Non foi posíbel gardar a mensaxe. Inténteo de novo',

	'item:object:messages' => 'Mensaxe',
	'collection:object:messages' => 'Mensaxes',

	/**
	* Status messages
	*/

	'messages:posted' => "Enviouse a mensaxe",
	'messages:success:delete:single' => 'Eliminouse a mensaxe',
	'messages:success:delete' => 'Eliminouse a mensaxe',
	'messages:success:read' => 'Marcouse a mensaxe como lida.',
	'messages:error:messages_not_selected' => 'Non hai ningunha mensaxe seleccionada.',
	'messages:error:delete:single' => 'Non foi posíbel eliminar a mensaxe.',

	/**
	* Email messages
	*/

	'messages:email:subject' => 'Ten unha nova mensaxe.',
	'messages:email:body' => "You have a new message from %s.

It reads:

%s

To view your messages, click here:
%s

To send %s a message, click here:
%s",

	/**
	* Error messages
	*/

	'messages:blank' => "Non pode gardar unha mensaxe co corpo baleiro.",
	'messages:nomessages' => "Non hai ningunha mensaxe.",
	'messages:user:nonexist' => "Non foi posíbel atopar o destinatario na base de datos de usuarios.",
	'messages:user:blank' => "Non indicou ningún destinatario.",
	'messages:user:self' => "Non pode enviarse unha mensaxe a vostede mesmo.",

	'messages:deleted_sender' => 'Usuario eliminado.',

);
